@@ -2,7 +2,7 @@ context("Test create webprocess object")
 test_that("creation of webprocess object", {
   testthat::skip_on_cran()
   expect_is(webprocess(), "webprocess")
-  wp <- webprocess(url = 'http://cida-test.er.usgs.gov/gdp/process/WebProcessingService')
+  wp <- webprocess(url = 'https://cida-test.er.usgs.gov/gdp/process/WebProcessingService')
   expect_is(wp, "webprocess")
 })
 
@@ -10,11 +10,11 @@ context('test modifying webprocess object')
 
 test_that("webprocess object is modified correctly", {
   testthat::skip_on_cran()
-  wp <- webprocess(url = 'http://cida-test.er.usgs.gov/gdp/process/WebProcessingService')
+  wp <- webprocess(url = 'https://cida-test.er.usgs.gov/gdp/process/WebProcessingService')
   # test setting url also changes util
-  expect_equal(slot(wp, 'UTILITY_URL'), 'http://cida-test.er.usgs.gov/gdp/utility/WebProcessingService')
-  url(wp) = 'http://cida-test.er.usgs.gov/gdp/process/WebProcessingService'
-  expect_equal(url(wp), url(wp <- webprocess(url = 'http://cida-test.er.usgs.gov/gdp/process/WebProcessingService')))
+  expect_equal(slot(wp, 'UTILITY_URL'), 'https://cida-test.er.usgs.gov/gdp/utility/WebProcessingService')
+  url(wp) = 'https://cida-test.er.usgs.gov/gdp/process/WebProcessingService'
+  expect_equal(url(wp), url(wp <- webprocess(url = 'https://cida-test.er.usgs.gov/gdp/process/WebProcessingService')))
 
 })
 
